@@ -388,7 +388,6 @@ module SiSU
             SiSU_Source::SiSUpodSource.new(@opt).read
           end
           if @opt.act[:share_source][:set]==:on
-#REDO
             require_relative 'share_src'               # -s     share_src.rb
             begin
             ensure
@@ -516,6 +515,9 @@ module SiSU
       SiSU_Env::InfoProcessingFlag.new
       if @opt.act[:version_info][:set]==:on              #% version information
         SiSU_Env::InfoAbout.new(@opt).sisu_version
+        if @opt.cmd =~/[vVM]/
+          SiSU_Screen::Ansi.new(@opt.cmd,' ' + File.dirname(__FILE__)).grey
+        end
       end
       if @opt.act[:dal][:set]==:on \
       or @opt.act[:maintenance][:set]==:on               #% --maintenance, -m for -C
