@@ -64,6 +64,10 @@
 YEAR='2013'
 Sfx={
   txt:                       '.txt',
+  txt_textile:               '.textile',
+  txt_asciidoc:              '.asciidoc.txt',
+  txt_markdown:              '.md',
+  txt_rst:                   '.rst',
   html:                      '.html',
   xhtml:                     '.xhtml',
   xml:                       '.xml',
@@ -72,6 +76,10 @@ Sfx={
   xml_scaffold:              '.scaffold.xml',
   xml_scaffold_structure_sisu:     '.scaffold.sisu.xml',
   xml_scaffold_structure_collapse: '.scaffold.collapse.xml',
+  xml_docbook:               '.docbook.xml',
+  xml_docbook_article:       '.article.docbook.xml',
+  xml_docbook_book:          '.book.docbook.xml',
+  xml_fictionbook:           '.fb2',
   epub:                      '.epub',
   epub_xhtml:                '.xhtml',
   odt:                       '.odt',
