@@ -162,8 +162,8 @@ module SiSU_HTML
       end
       def tuned_file_instructions
         @tell=SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set])
-        dal_array=@particulars.dal_array # dal file drawn here
-        tuned_file_array=SiSU_HTML_Tune::Tune.new(dal_array,@md).songsheet
+        ao_array=@particulars.ao_array # ao file drawn here
+        tuned_file_array=SiSU_HTML_Tune::Tune.new(ao_array,@md).songsheet
         tuned_file_array
       end
     end
