@@ -66,14 +66,14 @@ module SiSU_Particulars
     include SiSU_Env
   require_relative 'param'                              # param.rb
     include SiSU_Param
-  require_relative 'dal'                                # dal.rb
+  require_relative 'ao'                                 # ao.rb
   class CombinedSingleton
     include Singleton
     def get_all(opt)
       set_env(opt)
       set_file(opt)
       set_md(opt)
-      set_dal(opt)                #needs @md
+      set_ao(opt)                #needs @md
     end
     def get_env(opt)
       set_env(opt)
@@ -84,8 +84,8 @@ module SiSU_Particulars
     def get_md(opt)
       set_md(opt)
     end
-    def get_dal_array(opt)
-      set_dal(opt)                #needs @md
+    def get_ao_array(opt)
+      set_ao(opt)                #needs @md
     end
     def get_env_md(opt)
       set_env(opt)
@@ -149,10 +149,10 @@ module SiSU_Particulars
         end
       end
     end
-    attr_accessor :opt,:dal_array
-    def set_dal(opt)
+    attr_accessor :opt,:ao_array
+    def set_ao(opt)
       begin
-        @dal_array=SiSU_DAL::Source.new(opt).get
+        @ao_array=SiSU_AO::Source.new(opt).get
         self
       rescue
         SiSU_Errors::Rescued.new($!,$@,opt.cmd,opt.fnl).location do
@@ -162,7 +162,7 @@ module SiSU_Particulars
     end
     def set_sst_idx(opt)
       begin
-        @sst_idx=SiSU_DAL::Source.new(opt).get_idx_sst
+        @sst_idx=SiSU_AO::Source.new(opt).get_idx_sst
         self
       rescue
         SiSU_Errors::Rescued.new($!,$@,opt.cmd,opt.fnl).location do
@@ -172,7 +172,7 @@ module SiSU_Particulars
     end
     def set_raw_idx(opt)
       begin
-        @raw_idx=SiSU_DAL::Source.new(opt).get_idx_raw
+        @raw_idx=SiSU_AO::Source.new(opt).get_idx_raw
         self
       rescue
         SiSU_Errors::Rescued.new($!,$@,opt.cmd,opt.fnl).location do
@@ -182,7 +182,7 @@ module SiSU_Particulars
     end
     def set_html_idx(opt)
       begin
-        @html_idx=SiSU_DAL::Source.new(opt).get_idx_html
+        @html_idx=SiSU_AO::Source.new(opt).get_idx_html
         self
       rescue
         SiSU_Errors::Rescued.new($!,$@,opt.cmd,opt.fnl).location do
@@ -192,7 +192,7 @@ module SiSU_Particulars
     end
     def set_xhtml_idx(opt)
       begin
-        @xhtml_idx=SiSU_DAL::Source.new(opt).get_idx_xhtml
+        @xhtml_idx=SiSU_AO::Source.new(opt).get_idx_xhtml
         self
       rescue
         SiSU_Errors::Rescued.new($!,$@,opt.cmd,opt.fnl).location do
@@ -204,7 +204,7 @@ module SiSU_Particulars
     def set_nametags_map(opt)
       begin
         opt=@md ? @md : opt
-        @nametags_map=SiSU_DAL::Source.new(opt).get_map_nametags
+        @nametags_map=SiSU_AO::Source.new(opt).get_map_nametags
         self
       rescue
         if @md
@@ -221,7 +221,7 @@ module SiSU_Particulars
     attr_accessor :ocn_htmlseg_map
     def set_ocn_htmlseg_map(opt)
       begin
-        @ocn_htmlseg_map=SiSU_DAL::Source.new(@md).get_map_ocn_htmlseg
+        @ocn_htmlseg_map=SiSU_AO::Source.new(@md).get_map_ocn_htmlseg
         self
       rescue
         SiSU_Errors::Rescued.new($!,$@,opt.cmd,opt.fnl).location do
