@@ -262,7 +262,7 @@ module SiSU_TextRepresentation
              elsif FileTest.file?("#{@env.path.image_source_include}/#{i}")
                @env.path.image_source_include
              else
-               SiSU_Screen::Ansi.new(@md.opt.cmd,"ERROR - image:", %{"#{i}" missing}, "search locations: #{@env.path.image_source_include_local}, #{@env.path.image_source_include_remote} and #{@env.path.image_source_include}").error2 unless @md.opt.cmd =~/q/
+               SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],"ERROR - image:", %{"#{i}" missing}, "search locations: #{@env.path.image_source_include_local}, #{@env.path.image_source_include_remote} and #{@env.path.image_source_include}").error2 unless @md.opt.act[:quiet][:set]==:on
                nil
              end
              img_type = /\S+\.(png|jpg|gif)/.match(i)[1]
