@@ -168,7 +168,7 @@ module SiSU_TeX_Pdf
           end
           rows_new << r
         end
-        table=rows_new.join #@dob[:dal].obj=rows.join
+        table=rows_new.join #@dob[:ao].obj=rows.join
         ocn_display(@dob) + start_table + table + " #{end_table}\n\\end{tiny}"
       else ''
       end
@@ -213,7 +213,7 @@ module SiSU_TeX_Pdf
           end
           rows_new << r
         end
-        table=rows_new.join #@dob[:dal].obj=rows.join
+        table=rows_new.join #@dob[:ao].obj=rows.join
         ocn_display(@dob) + start_table + table + " #{end_table}\n\\end{tiny}"
       else ''
       end
