@@ -105,7 +105,7 @@ module SiSU_Urls
         'h --html (HTML scroll)'=>@fn[:doc],
         'I --texinfo (Info file)'=>'info',
         'i --manpage (manpage)'=>'manpage',
-        'm --dal (Document Abstraction)'=>'dal',
+        'm --ao (Document Abstraction)'=>'ao',
         'N --hash-digests (Digests md5/sha256)'=>@fn[:digest],
         'o --odt (ODF:ODT - Open Document)'=>@fn[:odf],
         'p --pdf (PDF landscape)'=>@fn[:pdf_l],
@@ -114,6 +114,12 @@ module SiSU_Urls
         's --source (sisu markup)'=>@opt.fno,
         'S --sisupod (sisupod)'=>@fn[:sisupod],
         't --txt (Plain-text (endnotes))'=>@fn[:plain],
+        '  --textile (textile txt)'=>@fn[:txt_textile],
+        '  --asciidoc (asciidoc txt)'=>@fn[:txt_asciidoc],
+        '  --markdown (markdown txt)'=>@fn[:txt_markdown],
+        '  --rst (rST restructured-text)'=>@fn[:txt_rst],
+        '  --docbook-book (DocBook Book)'=>@fn[:xml_docbook_book],
+        '  --fictionbook (Fictionbook)'=>@fn[:xml_fictionbook],
         'x --xml-sax (XML sax type)'=>@fn[:sax],
         'X --xml-dom (XML dom type)'=>@fn[:dom],
         '  --xml-scaffold-sisu (XML scaffold)'=>@fn[:xml_scaffold_structure_sisu],
@@ -153,6 +159,18 @@ module SiSU_Urls
       def text(x)
         SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.txt.dir}/#{@md.file.base_filename.txt}").result
       end
+      def textile(x)
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.textile.dir}/#{@md.file.base_filename.textile}").result
+      end
+      def asciidoc(x)
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.asciidoc.dir}/#{@md.file.base_filename.asciidoc}").result
+      end
+      def markdown(x)
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.markdown.dir}/#{@md.file.base_filename.markdown}").result
+      end
+      def rst(x)
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.rst.dir}/#{@md.file.base_filename.rst}").result
+      end
       def epub(x)
         SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.epub_viewer} #{@md.file.output_path.epub.dir}/#{@md.file.base_filename.epub}").result
       end
@@ -211,6 +229,12 @@ module SiSU_Urls
         def dom(x)
           SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}").result
         end
+        def docbook_book(x)
+          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_docbook_book.dir}/#{@md.file.base_filename.xml_docbook_book}").result
+        end
+        def fictionbook(x)
+          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_fictionbook.dir}/#{@md.file.base_filename.xml_fictionbook}").result
+        end
         def scaffold_structure_sisu(x)
           SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.web_browser} file://#{@md.file.output_path.xml_scaffold_structure_sisu.dir}/#{@md.file.base_filename.xml_scaffold_structure_sisu}").result
         end
@@ -249,7 +273,7 @@ module SiSU_Urls
         if x =~/^m/ \
         and @opt.cmd=~/m/ \
         and x=~/^[#{opt.cmd}]/
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"-#{x}","#{@prog.text_editor} #{@env.processing_path.dal}/#{@opt.fns}.meta").maintenance
+          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"-#{x}","#{@prog.text_editor} #{@env.processing_path.ao}/#{@opt.fns}.meta").maintenance
         end
         if x=~/^([hw])/ \
         and @opt.cmd=~/[hw]/ \
@@ -310,6 +334,22 @@ module SiSU_Urls
               and @opt.act[:txt][:set]==:on
                 show.text(x)
               end
+              if x=~/--textile\b/ \
+              and @opt.act[:txt_textile][:set]==:on
+                show.textile(x)
+              end
+              if x=~/--asciidoc\b/ \
+              and @opt.act[:txt_asciidoc][:set]==:on
+                show.asciidoc(x)
+              end
+              if x=~/--markdown\b/ \
+              and @opt.act[:txt_markdown][:set]==:on
+                show.markdown(x)
+              end
+              if x=~/--rst\b/ \
+              and @opt.act[:txt_rst][:set]==:on
+                show.rst(x)
+              end
               if x=~/--xhtml\b/ \
               and @opt.act[:xhtml][:set]==:on
                 show.xhtml(x)
@@ -406,6 +446,14 @@ module SiSU_Urls
               and @opt.act[:xml_sax][:set]==:on
                 show.xml.sax(x)
               end
+              if x=~/--docbook-book\b/ \
+              and @opt.act[:xml_docbook_book][:set]==:on
+                show.xml.docbook_book(x)
+              end
+              if x=~/--fictionbook\b/ \
+              and @opt.act[:xml_fictionbook][:set]==:on
+                show.xml.fictionbook(x)
+              end
               if x=~/--xml-scaffold-sisu\b/ \
               and @opt.act[:xml_scaffold_structure_sisu][:set]==:on
                 show.xml.scaffold_structure_sisu(x)
